@@ -7,10 +7,10 @@
 # that will be used to write a real start_proc.sh at deploy time.  The magic
 # strings will be substituted with real values by Python.
 
-export APP_SETTINGS_YAML="%(settings_path)s"
+export APP_SETTINGS_YAML="%(settings)s"
 export PORT=%(port)s
-export TMPDIR=%(tmpdir)s
-export HOME=%(tmpdir)s
+export TMPDIR=%(tmp)s
+export HOME=%(home)s
 
-source %(envsh_path)s
-exec %(cmd)s 
+source %(envsh)s
+%(cmd)s 
